import fs from 'fs'
import moment from 'moment'
import path from 'path'
import admzip from 'adm-zip'
import { resolve } from 'path'

const SERVER_LOG_FOLDER = './logs/server'
const CLIENTS_LOG_FOLDER = './logs/clients'
const LOG_EXTENSION = '.log'
const ZIP_EXTENSION = '.zip'

const createLogsFolders = () => {
    fs.mkdirSync(SERVER_LOG_FOLDER, { recursive: true, mode: '0777' })
    fs.mkdirSync(CLIENTS_LOG_FOLDER, { recursive: true, mode: '0777' })
}

const createClientLogFolder = (client) => {
    fs.mkdirSync(`${CLIENTS_LOG_FOLDER}/${client}`, { recursive: true, mode: '0777' })
}

const writeLogFile = (logMessage, client = null) => {
    try {
        let path

        if (client) {
            createClientLogFolder(client)
            path = resolve(`${CLIENTS_LOG_FOLDER}/${client}/${moment().format('yyyyMMDD')}.log`)
        } else {
            path = resolve(`${SERVER_LOG_FOLDER}/${moment().format('yyyyMMDD')}.log`)
        }

        fs.appendFileSync(path, logMessage)
    } catch (error) {
        console.log(error.message)
    }
}

const zipOlderLogFiles = async () => {
    try {
        let currentDate = moment().format('YYYYMMDD')
        zipOldLogFilesFromFolder(SERVER_LOG_FOLDER, currentDate)
        let clientLogsSubfolders = listDirectoryFiles(CLIENTS_LOG_FOLDER)
        
        for (let i = 0; i < clientLogsSubfolders.length; i++) {
            const subfolderPath = CLIENTS_LOG_FOLDER + '/' + clientLogsSubfolders[i]
            zipOldLogFilesFromFolder(subfolderPath, currentDate)
        }
    } catch (error) {
        console.log(error.message)
    }
}

const zipOldLogFilesFromFolder = (folderPath, currentDate) => {
    let serverLogs = listDirectoryFiles(folderPath, LOG_EXTENSION)
        
    for (let i = 0; i < serverLogs.length; i++) {
        const currentLog = serverLogs[i]
        let fileNameWithoutExtension = currentLog.replace(LOG_EXTENSION, '')

        if (fileNameWithoutExtension !== currentDate) {
            const zip = new admzip()
            let zippedFilePath = folderPath + '/' + fileNameWithoutExtension + ZIP_EXTENSION
            zip.addLocalFile(folderPath + '/' + currentLog)
            zip.writeZip(zippedFilePath)
            deleteFile(folderPath + '/' + currentLog)
        }
    }
}

const listDirectoryFiles = (directory, extension = null) => {
    try {
        let files = fs.readdirSync(directory)
        if (extension) files = files.filter(file => path.extname(file) === extension)
        return files
    } catch (error) {
        console.log(error.message)
        return []
    }
}

const deleteFile = (file) => {
    try {
        if (fs.existsSync(file)) {
            fs.unlinkSync(file)
        }
    } catch (error) {
        console.log(error.message)
    }
}

export { createLogsFolders, writeLogFile, zipOlderLogFiles }
