import { executeQuery } from '../Connection/QueriesExecutor.js'

const getConsumerDetails = async function (data) {
    const { CDCLIENTE, CDCONSUMIDOR } = data
    const result = await executeQuery({sql: 'GET_CONSUMER_DETAILS', 
        binds: {
            CDCLIENTE, CDCONSUMIDOR
        }
    })

    return result
}

const getSonsNotifValByParent = async (CDCLIENTE, NRCPFRESPCON) => {
    const result = await executeQuery({sql: 'GET_SONS_NOTIF_VAL',
        rawReturn: true,
        binds: {
            CDCLIENTE, NRCPFRESPCON
        }
    })

    return result
}

// A Query original considerava um campo que não existe no Oracle de testes
const getChildrenPhonesOriginal = async (CDCLIENTE, NRCPFRESPCON) => {
    const result = await executeQuery({sql: 'GET_CHILDREN_PHONES_ORIGINAL',
        rawReturn: true,
        binds: {
            CDCLIENTE, NRCPFRESPCON
        }
    })

    return result
}

// A Query alternativa busca um campo diferente do original, que parece conter o mesmo dado
const getChildrenPhonesAlternative = async (CDCLIENTE, NRCPFRESPCON) => {
    const result = await executeQuery({sql: 'GET_CHILDREN_PHONES_ALTERNATIVE',
        rawReturn: true,
        binds: {
            CDCLIENTE, NRCPFRESPCON
        }
    })

    return result
}

const updateChildrenPhonesOriginal = async (CDCLIENTE, NRCPFRESPCON, NRTELEFILHO, CDCONSUMIDOR) => {
    const result = await executeQuery({sql: 'UPDATE_CHILDREN_PHONES_ORIGINAL',
        binds: {
            CDCLIENTE, NRCPFRESPCON, NRTELEFILHO, CDCONSUMIDOR
        }
    })

    return result
}

const updateChildrenPhonesAlternative = async (CDCLIENTE, NRCPFRESPCON, NRTELECONS, CDCONSUMIDOR) => {
    const result = await executeQuery({sql: 'UPDATE_CHILDREN_PHONES_ALTERNATIVE',
        binds: {
            CDCLIENTE, NRCPFRESPCON, NRTELECONS, CDCONSUMIDOR
        }
    })

    return result
}

const updateSonNotifVal = async (VRNOTIFSALDO, CDCLIENTE, CDCONSUMIDOR) => {
    const result = await executeQuery({sql: 'UPDATE_SON_NOTIF_VAL',
        binds: {
            VRNOTIFSALDO, CDCLIENTE, CDCONSUMIDOR
        }
    })

    return result
}

const updateConsumerDetails = async (consDetails, body) => {
    const result = await executeQuery({sql: 'UPDATE_CONSUMER_DETAILS',
        binds: {
            CDCLIENTE: consDetails.CDCLIENTE,
            NMRESPCONS: body.NMRESPCONS,
            DSEMAILCONS: body.DSEMAILCONS,
            NRCELULARCONS: body.NRCELULARCONS,
            DSENDECONS: body.DSENDECONS,
            NRENDECONS: body.NRENDECONS,
            DSCOMPLENDECONS: body.DSCOMPLENDECONS,
            DSREFERENDECONS: body.DSREFERENDECONS,
            NRCEPCONS: body.NRCEPCONS,
            SGESTADO: body.SGESTADO,
            CDMUNICIPIO: body.CDMUNICIPIO,
            NMBAIRCONS: body.NMBAIRCONS,
            CDPAIS: body.CDPAIS,
            HABENVNOTIF: body.HABENVNOTIF,
            HABENVEMAIL: body.HABENVEMAIL,
            NRCPFRESPCON: body.NRCPFRESPCON,
        }
    })

    return result
}

const getPassword = async (consDetails) => {
    const { CDCLIENTE, NMLOGINCONS } = consDetails

    const result = await executeQuery({sql: 'GET_PASSWORD',
        binds: {
            CDCLIENTE, NMLOGINCONS
        }
    })

    return result
}

const changePassword = async (consDetails, encryptedNewPassword) => {
    const { CDCLIENTE, NMLOGINCONS } = consDetails
    
    const result = await executeQuery({sql: 'SQL_CHANGE_PASSWORD',
        binds: {
            CDCLIENTE, 
            NMLOGINCONS, 
            CDSENHACONSMD5: encryptedNewPassword
        }
    })

    return result
}

export default { 
    getConsumerDetails, 
    getSonsNotifValByParent,
    updateConsumerDetails,
    getPassword,
    changePassword,
    getChildrenPhonesOriginal,
    getChildrenPhonesAlternative,
    updateChildrenPhonesOriginal,
    updateChildrenPhonesAlternative,
    updateSonNotifVal
}
