import { methods } from './MethodsList.js'
import { log } from './../Controllers/LogController.js'

let handleRequest = (req, res) => {
    let body = ''
    req.on('data', chunk => {
        // convert Buffer to string
        body += (null || chunk).toString()
    })
    req.on('end', async () => {
        let result = null
        let resultCode = null
        let curMethod = null

        try {
            curMethod = methods[(req.originalUrl).replaceAll('/', '')]
            body = body || '{}'
            result = curMethod ? await curMethod({req, res, body: JSON.parse(body)}) : 'Método inválido'
            resultCode = curMethod ? 200 : 404
        } catch (error) {
            log({ type: 'error', message: `Erro na rota ${req.originalUrl}:\n${error.message}` })
            result = 'Método inválido'
            resultCode = 404
        }
  
        res.header('Access-Control-Allow-Headers', 'Origin, X-Requested-With, Content-Type, Accept')
        if (req.method === 'OPTIONS') {
            res.header('Access-Control-Allow-Methods', 'PUT, POST, PATCH, DELETE, GET')
            return res.status(200).json({})
        }

        res.status(resultCode)
        res.json({
            'sucesso': !!curMethod,
            'message': result ? result.message : null || result,
            data: result
        })
        res.end()
    })
    req.on('error', (err) => {
        log({ type: 'error', message: `Error in request:\n${err.message}` })
    
        // Send an error response
        res.writeHead(500, { 'Content-Type': 'application/json' })
        res.end(JSON.stringify({ error: 'Internal server error' }))
      })
}

export { handleRequest }